@@ -81,9 +81,9 @@ Balloon::Balloon(const TQString &text, const TQString &pix)
   setPalette(TQToolTip::palette());
   setAutoMask(true);
 
-  connect(caption, SIGNAL(clicked(int, int)), this, SIGNAL(signalBalloonClicked()));
-  connect(caption, SIGNAL(linkClicked(const TQString &)), this, SIGNAL(signalIgnoreButtonClicked()));
-  connect(caption, SIGNAL(linkClicked(const TQString &)), this, SLOT(deleteLater()));
+  connect(caption, TQ_SIGNAL(clicked(int, int)), this, TQ_SIGNAL(signalBalloonClicked()));
+  connect(caption, TQ_SIGNAL(linkClicked(const TQString &)), this, TQ_SIGNAL(signalIgnoreButtonClicked()));
+  connect(caption, TQ_SIGNAL(linkClicked(const TQString &)), this, TQ_SLOT(deleteLater()));
 }
 
 void Balloon::mousePressEvent(TQMouseEvent *e)
