@@ -99,10 +99,10 @@ FailedTransfers::FailedTransfers(TQWidget *parent, const char *name)
   
   layout->addWidget(m_list);
   
-  connect(KFTPQueue::Manager::self(), SIGNAL(failedTransferNew(KFTPQueue::FailedTransfer*)), this, SLOT(slotFailedTransferNew(KFTPQueue::FailedTransfer*)));
-  connect(KFTPQueue::Manager::self(), SIGNAL(failedTransferRemoved(long)), this, SLOT(slotFailedTransferRemoved(long)));
+  connect(KFTPQueue::Manager::self(), TQ_SIGNAL(failedTransferNew(KFTPQueue::FailedTransfer*)), this, TQ_SLOT(slotFailedTransferNew(KFTPQueue::FailedTransfer*)));
+  connect(KFTPQueue::Manager::self(), TQ_SIGNAL(failedTransferRemoved(long)), this, TQ_SLOT(slotFailedTransferRemoved(long)));
   
-  connect(m_list, SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)), this, SLOT(contextMenuRequested(TDEListView*, TQListViewItem*, const TQPoint&)));
+  connect(m_list, TQ_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)), this, TQ_SLOT(contextMenuRequested(TDEListView*, TQListViewItem*, const TQPoint&)));
   
   // Initialize the actions
   initActions();
@@ -114,11 +114,11 @@ FailedTransfers::~FailedTransfers()
 
 void FailedTransfers::initActions()
 {
-  m_restartAction = new TDEAction(i18n("&Restart Transfer"), "launch", TDEShortcut(), this, SLOT(slotRestart()), actionCollection(), "launch");
-  m_addToQueueAction = new TDEAction(i18n("&Add To Queue"), "queue", TDEShortcut(), this, SLOT(slotAddToQueue()), actionCollection(), "addtoqueue");
-  m_addAllToQueueAction = new TDEAction(i18n("Add All To Queue"), TDEShortcut(), this, SLOT(slotAddAllToQueue()), actionCollection(), "addalltoqueue");
-  m_removeAction = new TDEAction(i18n("R&emove"), "edit-delete", TDEShortcut(), this, SLOT(slotRemove()), actionCollection(), "remove");
-  m_removeAllAction = new TDEAction(i18n("Remove All"), TDEShortcut(), this, SLOT(slotRemoveAll()), actionCollection(), "removeall");
+  m_restartAction = new TDEAction(i18n("&Restart Transfer"), "launch", TDEShortcut(), this, TQ_SLOT(slotRestart()), actionCollection(), "launch");
+  m_addToQueueAction = new TDEAction(i18n("&Add To Queue"), "queue", TDEShortcut(), this, TQ_SLOT(slotAddToQueue()), actionCollection(), "addtoqueue");
+  m_addAllToQueueAction = new TDEAction(i18n("Add All To Queue"), TDEShortcut(), this, TQ_SLOT(slotAddAllToQueue()), actionCollection(), "addalltoqueue");
+  m_removeAction = new TDEAction(i18n("R&emove"), "edit-delete", TDEShortcut(), this, TQ_SLOT(slotRemove()), actionCollection(), "remove");
+  m_removeAllAction = new TDEAction(i18n("Remove All"), TDEShortcut(), this, TQ_SLOT(slotRemoveAll()), actionCollection(), "removeall");
 }
 
 void FailedTransfers::updateActions()
